pub fn print_verb_table()Expand description
Print the full verb table to stdout, sorted alphabetically by name.
Each line is two-space-indented <name> <summary> with names left-
padded to the widest name.
pub fn print_verb_table()Print the full verb table to stdout, sorted alphabetically by name.
Each line is two-space-indented <name> <summary> with names left-
padded to the widest name.